﻿## Instructions

### Follow these steps to add FlashLog© to your project

1. Install nuget postsharp 6.10.5 (in first run only you should create your postsharp license)
2. Create a file "nlog.config" in your project root, change it's "Copy to output directory" to "Copy if newer", and copy this content:

```bash
<?xml version="1.0" encoding="utf-8" ?>
<nlog xmlns="http://www.nlog-project.org/schemas/NLog.xsd"
      xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

  <extensions>
    <add assembly="Microsoft.ApplicationInsights.NLogTarget" />
  </extensions>

  <targets>
    <target
          xsi:type="Console"
          name="consoleTarget"
          layout="${longdate} | ${level:uppercase=false} | ${logger} | ${message}">
    </target>
    <target
          xsi:type="ApplicationInsightsTarget"
          name="aiTarget"
          instrumentationKey="[instrumentationKey]">
      <contextproperty name="threadid" layout="${threadid}" />
    </target>
    <target
          xsi:type="File"
          name="fileTarget"
          fileName="c:\logs\log.log"
          layout="${longdate} | ${level:uppercase=false} | ${logger} | ${message}" />
    <target
          name="Mail"
          xsi:type="Mail"
          html="true"
          subject="AspectLogger Trace"
          body="${longdate} | ${level:uppercase=false} | ${logger} | ${message}"
          to="[To_mail]"
          from="[From_mail]"
          Encoding="UTF-8"
          smtpUsername="[From_mail]"
          enableSsl="True"
          smtpPassword="[Password]"
          smtpAuthentication="Basic"
          smtpServer="[smtp_server]"
          smtpPort="[smtp_port]" />
  </targets>

  <rules>
    <logger name="*" minlevel="Trace" writeTo="consoleTarget,aiTarget,fileTarget" />
    <logger name="*" minlevel="Error" writeTo="consoleTarget,aiTarget,fileTarget,Mail" />
  </rules>
</nlog>
```

remember!
this is your output settings:
writeTo="consoleTarget,aiTarget,fileTarget"

consoleTarget = console window output
aiTarget = application insights
fileTarget = file in c:\logs\log.log

in case of exception a mail log too

3. Change all the details according to yours
4. create a file "app.config" in your executable, change it's "Copy to output directory" to "Copy if newer", and copy this content:

```bash
<?xml version="1.0" encoding="utf-8" ?>
<configuration>
  <appSettings>
    <add key="logExceptionsOnly" value="false"/>
  </appSettings>
</configuration>
```

keep in mind that:
```bash
   <add key="logExceptionsOnly" value="true"/> //will print exceptions only
```

```bash
   <add key="logExceptionsOnly" value="false"/> //will print EVERY function entry + exceptions
```


5. We are all set! now all you need to do is add an attribute [AspectLogger] in your class

## Example for class with AspectLogger


```bash

class Program
{
    static void Main(string[] args)
    {
        MyClass testClass = new ();

        testClass.Func1();
        testClass.Func2();
    }
}


// this is the logger attribute that will log every step and exception of your class
[AspectLogger]
public class MyClass
{
	public void Func1()
	{}

	public void Func2()
	{}
}


```

the output will be:
```bash
2022-01-02 09:02:49.4440 | Info | FlashLog.Logging.NLogLogger | Entering Method:".ctor" 
2022-01-03 09:02:49.4441 | Info | FlashLog.Logging.NLogLogger | Entering Method:"Func1" 
2022-01-03 09:02:49.4442 | Info | FlashLog.Logging.NLogLogger | Entering Method:"Func2" 
```

## Manual Print

### FlashLog can also print log manually, add this code wherever you need to log.


```bash
Logger.GetLogger().Log("Print1");
```

the output will be:
```bash
2022-01-03 09:02:49.4580 | Info | FlashLog.Logging.NLogLogger | Print1 
```